@@ -14,7 +14,10 @@
 #include <KHTMLView>
 #include <KToolBarPopupAction>
 #include <KSharedConfig>
-#include <ki18n_version.h>
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 36, 0)
+#include <docbookxslt.h>
+#endif
 
 #include <QFileInfo>
 #include <QClipboard>
@@ -94,8 +97,13 @@ QString View::langLookup( const QString &fname )
 {
     QStringList search;
 
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 36, 0)
+    // retrieve the local search path
+    const QStringList localDoc = KDocTools::documentationDirs();
+#else
     // assemble the local search paths
     const QStringList localDoc = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("doc/HTML"), QStandardPaths::LocateDirectory);
+#endif
 
     QStringList langs = KLocalizedString::languages();
     langs.append(QStringLiteral("en"));
